@@ -99,7 +99,7 @@ DOCUMENTATION__install = SwaggerDocumentation(
                             "you. This is a JAAQL login for superjaaql so it is entirely independent of the postgres password at "
                             "the database level. If you do not supply this password, you will not be able to login to jaaql "
                             "authenticating as postgres with the local database node. You can set this up later if you want ",
-                example=["sup3rjaaqlpa55word"],
+                example=["passw0rd"],
                 condition="If you want to give the superjaaql user a login",
                 required=False,
                 arg_type=str
@@ -1004,6 +1004,16 @@ ARG_RES__email_template_body = [
         required=False,
         condition="Is data being replaced"
     ),
+    SwaggerArgumentResponse(
+        name=KEY__data_validation_view,
+        description="A view which is used to select the data from after insertion into the data validation table. Cannot be present if the data "
+        "validation table is null. If null and data validation table is present, data will be selected from the data validation table. Data is "
+        "selected using the primary key of the data validation table from which one and only one row must be returned from the view",
+        arg_type=str,
+        example=["my_data_validation_table"],
+        required=False,
+        condition="Is a view being used to replace data"
+    ),
     SwaggerArgumentResponse(
         name=KEY__recipient_validation_view,
         description="Allowed recipients are SELECT key, email FROM this_view WHERE "
